#--
# Trialday
#
# Trialday is a small web framework for writing simple JSON APIs.
# It's Rack based (https://rack.github.io/).
#
# The architecture is composed of 3 main layers, that are represented
# below with base, mains and router.
#
# Trial day is a reverse engineering of Sinatra
# [https://github.com/sinatra/sinatra/tree/master/lib/sinatra]
#++
require 'rack'
require 'trialday/base'
require 'trialday/router'
require 'trialday/main'


# = Trialday Delegator
#
# In order to public expose the get and set methods, we use metaprogramming
# defining both of them in a dynamic way. The defined methods are then
# extended in this main file to it they can be accessed from outside.
# The idea comes from Sinatra base: lib/sinatra/base.rb#L1918
#
# PS: include would include the module in Object
# while extend only extends the `main` object
extend Trialday::Delegator

# = Rack Builder
#
# Implements a small DSL to iteratively construct Rack applications.
class Rack::Builder
  include Trialday::Delegator
end
