# = Trialday Router
#
# The Router for Trialday framework.
# The Router is responsible to keep a collections of paths
# and knows where and what to return. It verifies if the request is a get
# or post, and check to see if the API was pre-defined with an response for
# the desired call.
#
# This class uses ideas from Sinatra, and could be extensively improved.
# For now, it uses a routes list that could be tweaked.
# The framework also includes a 'not_foud' route in case the Router wasn't
# configured to respond to a specific call.
# [see Sinatra: ib/sinatra/base.rb#L1602]
require 'json'

module Trialday
  class Router
    @@routes = []

    def initialize(request)
      @request = request
    end

    def route!
      routes_list.each do |r|
        if action == r['path']
          verb = @request.get? ? 'GET' : 'POST'
          if verb == 'GET'
            return [200, { "Content-Type" => "application/json" }, [r['body'].call.to_json]]
          elsif verb == 'POST'
            return [200, { "Content-Type" => "application/json" }, [@request.body.read]]
          end
        end
      end

      not_found
    end

    def action
      '/'+ route_info[:resource]
    end

    def routes_list
      @@routes
    end

    class << self
      def route(path, verb, &block)
        @@routes << {"path"=>path, "body"=>block, "verb"=>"GET"}
      end
    end

    private

    def not_found(msg = "Route not found.")
      [404, { "Content-Type" => "text/plain" }, [msg]]
    end

    def route_info
      @route_info ||= begin
        resource = path_fragments[0]
        { resource: resource }
      end
    end

    def find_id_and_action(fragment)
      @request.get? ? :index : :create
    end

    def add_route_info_to_request_params!
      @request.params.merge!(route_info)
    end

    def path_fragments
      @fragments ||= @request.path.split("/").reject { |s| s.empty? }
    end

  end
end